package hu.kozadat.oaiaggregator.service;

import org.joda.time.DateTime;
import org.joda.time.LocalDateTime;
import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

import java.util.Date;

/**
 * Created by tnagy on 2015.10.14..
 */
public class JodaTimeUtils {

    public static String dateToString(Date date, String pattern) {
        if (date == null) {
            return null;
        }
        DateTimeFormatter formatter = DateTimeFormat.forPattern(pattern);
        DateTime dateTime = new DateTime(date.getTime());
        return formatter.print(dateTime);
    }

    public static String dateToISOString(Date date) {
        if (date == null) {
            return null;
        }
        DateTimeFormatter formatter = ISODateTimeFormat.basicDate();
        DateTime dateTime = new DateTime(date.getTime());
        return formatter.print(dateTime);
    }

    public static String dateToISODateTimeString(Date date) {
        if (date == null) {
            return null;
        }
        DateTimeFormatter formatter = ISODateTimeFormat.basicDateTime();
        DateTime dateTime = new DateTime(date.getTime());
        return formatter.print(dateTime);
    }

    public static String dateToUTCISODateString(Date date) {
        if (date == null) {
            return null;
        }
        DateTime dateTime = new DateTime(date.getTime());
        DateTimeFormatter formatter = ISODateTimeFormat.date();
        return formatter.withZoneUTC().print(dateTime);
    }

    public static String dateToUTCISODateTimeString(Date date) {
        if (date == null) {
            return null;
        }
        DateTime dateTime = new DateTime(date.getTime());
        DateTimeFormatter formatter = ISODateTimeFormat.dateTimeNoMillis();
        return formatter.withZoneUTC().print(dateTime);
    }

    public static Date parseStringAsISODate(String dateString) {
        if (StringUtils.isStringNullOrEmpty(dateString)) {
            return null;
        }
        DateTimeFormatter formatter = ISODateTimeFormat.date();
        DateTime dateTime = formatter.withZoneUTC().parseDateTime(dateString);
        return dateTime.toDate();
    }

    public static Date parseStringAsISODateTime(String dateString) {
        if (StringUtils.isStringNullOrEmpty(dateString)) {
            return null;
        }
        DateTimeFormatter formatter = ISODateTimeFormat.dateTimeNoMillis();
        DateTime dateTime = formatter.withZoneUTC().parseDateTime(dateString);
        return dateTime.toDate();
    }

    public static Date parseISODateString(String dateString) {
        if (dateString != null) {
            if (dateString.contains("T") && dateString.contains("Z")) {
                return JodaTimeUtils.parseStringAsISODateTime(dateString);
            } else {
                return JodaTimeUtils.parseStringAsISODate(dateString);
            }
        } else {
            return null;
        }
    }

    public static String dateToLocalString(Date date, String pattern) {
        if (date == null) {
            return null;
        }
        LocalDateTime dateTime = new LocalDateTime(date.getTime());
        DateTimeFormatter formatter = DateTimeFormat.forPattern(pattern);
        return formatter.print(dateTime);
    }

}
